==> haskell-system-filepath-0.4.14-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-system-filepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: system-filepath
version: 0.4.14
id: system-filepath-0.4.14-F6tWnQ8w6Re4FOKikOPtM5
key: system-filepath-0.4.14-F6tWnQ8w6Re4FOKikOPtM5
license: MIT
copyright: John Millikin 2010-2012
maintainer: FP Complete <michael@fpcomplete.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://github.com/fpco/haskell-filesystem
synopsis: High-level, byte-based file and directory path manipulations (deprecated)
description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx
category: System
abi: de02d1a63a26070dfbb21ed9799ddc29
exposed: True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules
hidden-modules: Filesystem.Path.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/system-filepath-0.4.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/system-filepath-0.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/system-filepath-0.4.14
hs-libraries: HSsystem-filepath-0.4.14-F6tWnQ8w6Re4FOKikOPtM5
depends:
    base-4.12.0.0 bytestring-0.10.8.2 deepseq-1.4.4.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock
haddock-html: /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-filepath-0.4.14-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-system-filepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: system-filepath
version: 0.4.14
id: system-filepath-0.4.14-GW1RjgWxWC0AXLwQ3KWQjU
key: system-filepath-0.4.14-GW1RjgWxWC0AXLwQ3KWQjU
license: MIT
copyright: John Millikin 2010-2012
maintainer: FP Complete <michael@fpcomplete.com>
author: John Millikin <jmillikin@gmail.com>
stability: experimental
homepage: https://github.com/fpco/haskell-filesystem
synopsis: High-level, byte-based file and directory path manipulations (deprecated)
description:
    Please see: https://plus.google.com/+MichaelSnoyman/posts/Ft5hnPqpgEx
category: System
abi: f3815a73b87baa582435f46f1e7fe833
exposed: True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules
hidden-modules: Filesystem.Path.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/system-filepath-0.4.14
library-dirs: /usr/lib/ghc-8.6.5/site-local/system-filepath-0.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/system-filepath-0.4.14
hs-libraries: HSsystem-filepath-0.4.14-GW1RjgWxWC0AXLwQ3KWQjU
depends:
    base-4.12.0.0 bytestring-0.10.8.2 deepseq-1.4.4.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock
haddock-html: /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
